<?php

namespace App\Http\Controllers;

use App\Models\Code;
use App\Models\Exam;
use App\Models\TeamCategory;
use App\Models\TeamWork;
use App\Traits\Helpers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;

class TeamWorkController extends Controller
{
    use Helpers;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $categories = TeamCategory::where('user_id', Auth::id())->get();
        $categoriesCount = TeamCategory::where('user_id', Auth::id())->count();
        return view('frontend.team.index', compact('categories', 'categoriesCount'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create($id)
    {
        $category = TeamCategory::find($id);
        return view('frontend.team.create', compact('category'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $price = 19.99;
        $total_price = $request->number * $price;
        
        $this->payment_with_data("8ac7a4c7818e8a9e01818f6e3b1d01c4", (string)$total_price, $request->card_number, $request->owner_name, $request->month, $request->year, $request->cvv);
        
        if(session()->has('error')) {
            session()->flash('message', trans('main-sidebar.error'));
            return redirect()->back();
        }
        
        $team = new TeamWork();
        $team['user_id'] = Auth::id();
        $team['category_id'] = $request->category_id;
        $team['number_of_exams'] = $request->number;
        $team['name'] = $request->name;
        $team->save();

        for ($x = 0; $x < $request->number; $x++) {
            $code = new Code();

            $code['code'] = Str::random(16);
            $code['user_id'] = $team->id;
            $code->save();
        }

        


        
        session()->flash('message', 'لقد تم إنشاء الفريق بنجاح');
        return redirect()->route('team.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\TeamWork  $teamWork
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $teams = TeamWork::where('category_id', $id)->get();
        return view('frontend.team.show', compact('teams'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\TeamWork  $teamWork
     * @return \Illuminate\Http\Response
     */
    public function edit(TeamWork $teamWork)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\TeamWork  $teamWork
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, TeamWork $teamWork)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\TeamWork  $teamWork
     * @return \Illuminate\Http\Response
     */
    public function destroy(TeamWork $teamWork)
    {
        //
    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\TeamWork  $teamWork
     * @return \Illuminate\Http\Response
     */
    public function codes($team_id)
    {
        $codes = Code::where('user_id', $team_id)->get();
        return view('frontend.team.codes', compact('codes'));
    }

    public function exam()
    {
        return view('frontend.start');
    }

    public function exam_details($exam_code) {
        $exam = Exam::where('exam_code', $exam_code)->first();
       return view('frontend.team.exam_details', compact('exam'));
    }
}
